# spotify_openapi
You can use [Spotify's Web API](https://developer.spotify.com/documentation/web-api) to discover music and podcasts, manage your Spotify library, control audio playback, and much more.

In order to make successful Web API requests you will need a valid access token. One can be obtained through [OAuth 2.0](https://developer.spotify.com/documentation/general/guides/authorization-guide/).

This Dart package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.0.1
- Build package: org.openapitools.codegen.languages.DartDioClientCodegen

## Requirements

* Dart 3.0.6+ or Flutter 3.10.6+

## Installation & Usage

### pub.dev (Recommended)
To pull the package from [pub.dev](https://pub.dev), include the following in your pubspec.yaml
```yaml
dependencies:
  spotify_openapi: 0.0.1
```

### Github
To pull the package from Github, include the following in your pubspec.yaml
```yaml
dependencies:
  spotify_openapi:
    git:
      url: https://github.com/aidan-mundy/spotify-api-dart.git
      #ref: main
```

### Local development
To use a local copy of the package, include the following in your pubspec.yaml
```yaml
dependencies:
  spotify_openapi:
    path: /path/to/spotify_openapi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```dart
import 'package:spotify_openapi/spotify_openapi.dart';


final api = SpotifyOpenapi().getAlbumsApi();
final String ids = 382ObEPsp2rxGrnsizN5TX,1A2GTWGtFfWp7KSQTwWOyo,2noRn2Aes5aoNVsU6iWThc; // String | 

try {
    final response = await api.checkUsersSavedAlbums(ids);
    print(response);
} catch on DioException (e) {
    print("Exception when calling AlbumsApi->checkUsersSavedAlbums: $e\n");
}

```

## Documentation for API Endpoints

All URIs are relative to *https://api.spotify.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
[*AlbumsApi*](doc/AlbumsApi.md) | [**checkUsersSavedAlbums**](doc/AlbumsApi.md#checkuserssavedalbums) | **GET** /me/albums/contains | Check User&#39;s Saved Albums 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getAnAlbum**](doc/AlbumsApi.md#getanalbum) | **GET** /albums/{id} | Get Album 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getAnAlbumsTracks**](doc/AlbumsApi.md#getanalbumstracks) | **GET** /albums/{id}/tracks | Get Album Tracks 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getAnArtistsAlbums**](doc/AlbumsApi.md#getanartistsalbums) | **GET** /artists/{id}/albums | Get Artist&#39;s Albums 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getMultipleAlbums**](doc/AlbumsApi.md#getmultiplealbums) | **GET** /albums | Get Several Albums 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getNewReleases**](doc/AlbumsApi.md#getnewreleases) | **GET** /browse/new-releases | Get New Releases 
[*AlbumsApi*](doc/AlbumsApi.md) | [**getUsersSavedAlbums**](doc/AlbumsApi.md#getuserssavedalbums) | **GET** /me/albums | Get User&#39;s Saved Albums 
[*AlbumsApi*](doc/AlbumsApi.md) | [**removeAlbumsUser**](doc/AlbumsApi.md#removealbumsuser) | **DELETE** /me/albums | Remove Users&#39; Saved Albums 
[*AlbumsApi*](doc/AlbumsApi.md) | [**saveAlbumsUser**](doc/AlbumsApi.md#savealbumsuser) | **PUT** /me/albums | Save Albums for Current User 
[*ArtistsApi*](doc/ArtistsApi.md) | [**checkCurrentUserFollows**](doc/ArtistsApi.md#checkcurrentuserfollows) | **GET** /me/following/contains | Check If User Follows Artists or Users 
[*ArtistsApi*](doc/ArtistsApi.md) | [**followArtistsUsers**](doc/ArtistsApi.md#followartistsusers) | **PUT** /me/following | Follow Artists or Users 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getAnArtist**](doc/ArtistsApi.md#getanartist) | **GET** /artists/{id} | Get Artist 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getAnArtistsAlbums**](doc/ArtistsApi.md#getanartistsalbums) | **GET** /artists/{id}/albums | Get Artist&#39;s Albums 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getAnArtistsRelatedArtists**](doc/ArtistsApi.md#getanartistsrelatedartists) | **GET** /artists/{id}/related-artists | Get Artist&#39;s Related Artists 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getAnArtistsTopTracks**](doc/ArtistsApi.md#getanartiststoptracks) | **GET** /artists/{id}/top-tracks | Get Artist&#39;s Top Tracks 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getFollowed**](doc/ArtistsApi.md#getfollowed) | **GET** /me/following | Get Followed Artists 
[*ArtistsApi*](doc/ArtistsApi.md) | [**getMultipleArtists**](doc/ArtistsApi.md#getmultipleartists) | **GET** /artists | Get Several Artists 
[*ArtistsApi*](doc/ArtistsApi.md) | [**unfollowArtistsUsers**](doc/ArtistsApi.md#unfollowartistsusers) | **DELETE** /me/following | Unfollow Artists or Users 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**checkUsersSavedAudiobooks**](doc/AudiobooksApi.md#checkuserssavedaudiobooks) | **GET** /me/audiobooks/contains | Check User&#39;s Saved Audiobooks 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**getAnAudiobook**](doc/AudiobooksApi.md#getanaudiobook) | **GET** /audiobooks/{id} | Get an Audiobook 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**getAudiobookChapters**](doc/AudiobooksApi.md#getaudiobookchapters) | **GET** /audiobooks/{id}/chapters | Get Audiobook Chapters 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**getMultipleAudiobooks**](doc/AudiobooksApi.md#getmultipleaudiobooks) | **GET** /audiobooks | Get Several Audiobooks 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**getUsersSavedAudiobooks**](doc/AudiobooksApi.md#getuserssavedaudiobooks) | **GET** /me/audiobooks | Get User&#39;s Saved Audiobooks 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**removeAudiobooksUser**](doc/AudiobooksApi.md#removeaudiobooksuser) | **DELETE** /me/audiobooks | Remove User&#39;s Saved Audiobooks 
[*AudiobooksApi*](doc/AudiobooksApi.md) | [**saveAudiobooksUser**](doc/AudiobooksApi.md#saveaudiobooksuser) | **PUT** /me/audiobooks | Save Audiobooks for Current User 
[*CategoriesApi*](doc/CategoriesApi.md) | [**getACategoriesPlaylists**](doc/CategoriesApi.md#getacategoriesplaylists) | **GET** /browse/categories/{category_id}/playlists | Get Category&#39;s Playlists 
[*CategoriesApi*](doc/CategoriesApi.md) | [**getACategory**](doc/CategoriesApi.md#getacategory) | **GET** /browse/categories/{category_id} | Get Single Browse Category 
[*CategoriesApi*](doc/CategoriesApi.md) | [**getCategories**](doc/CategoriesApi.md#getcategories) | **GET** /browse/categories | Get Several Browse Categories 
[*ChaptersApi*](doc/ChaptersApi.md) | [**getAChapter**](doc/ChaptersApi.md#getachapter) | **GET** /chapters/{id} | Get a Chapter 
[*ChaptersApi*](doc/ChaptersApi.md) | [**getAudiobookChapters**](doc/ChaptersApi.md#getaudiobookchapters) | **GET** /audiobooks/{id}/chapters | Get Audiobook Chapters 
[*ChaptersApi*](doc/ChaptersApi.md) | [**getSeveralChapters**](doc/ChaptersApi.md#getseveralchapters) | **GET** /chapters | Get Several Chapters 
[*EpisodesApi*](doc/EpisodesApi.md) | [**checkUsersSavedEpisodes**](doc/EpisodesApi.md#checkuserssavedepisodes) | **GET** /me/episodes/contains | Check User&#39;s Saved Episodes 
[*EpisodesApi*](doc/EpisodesApi.md) | [**getAShowsEpisodes**](doc/EpisodesApi.md#getashowsepisodes) | **GET** /shows/{id}/episodes | Get Show Episodes 
[*EpisodesApi*](doc/EpisodesApi.md) | [**getAnEpisode**](doc/EpisodesApi.md#getanepisode) | **GET** /episodes/{id} | Get Episode 
[*EpisodesApi*](doc/EpisodesApi.md) | [**getMultipleEpisodes**](doc/EpisodesApi.md#getmultipleepisodes) | **GET** /episodes | Get Several Episodes 
[*EpisodesApi*](doc/EpisodesApi.md) | [**getUsersSavedEpisodes**](doc/EpisodesApi.md#getuserssavedepisodes) | **GET** /me/episodes | Get User&#39;s Saved Episodes 
[*EpisodesApi*](doc/EpisodesApi.md) | [**removeEpisodesUser**](doc/EpisodesApi.md#removeepisodesuser) | **DELETE** /me/episodes | Remove User&#39;s Saved Episodes 
[*EpisodesApi*](doc/EpisodesApi.md) | [**saveEpisodesUser**](doc/EpisodesApi.md#saveepisodesuser) | **PUT** /me/episodes | Save Episodes for Current User 
[*GenresApi*](doc/GenresApi.md) | [**getRecommendationGenres**](doc/GenresApi.md#getrecommendationgenres) | **GET** /recommendations/available-genre-seeds | Get Available Genre Seeds 
[*LibraryApi*](doc/LibraryApi.md) | [**changePlaylistDetails**](doc/LibraryApi.md#changeplaylistdetails) | **PUT** /playlists/{playlist_id} | Change Playlist Details 
[*LibraryApi*](doc/LibraryApi.md) | [**checkCurrentUserFollows**](doc/LibraryApi.md#checkcurrentuserfollows) | **GET** /me/following/contains | Check If User Follows Artists or Users 
[*LibraryApi*](doc/LibraryApi.md) | [**checkUsersSavedAlbums**](doc/LibraryApi.md#checkuserssavedalbums) | **GET** /me/albums/contains | Check User&#39;s Saved Albums 
[*LibraryApi*](doc/LibraryApi.md) | [**checkUsersSavedAudiobooks**](doc/LibraryApi.md#checkuserssavedaudiobooks) | **GET** /me/audiobooks/contains | Check User&#39;s Saved Audiobooks 
[*LibraryApi*](doc/LibraryApi.md) | [**checkUsersSavedEpisodes**](doc/LibraryApi.md#checkuserssavedepisodes) | **GET** /me/episodes/contains | Check User&#39;s Saved Episodes 
[*LibraryApi*](doc/LibraryApi.md) | [**checkUsersSavedShows**](doc/LibraryApi.md#checkuserssavedshows) | **GET** /me/shows/contains | Check User&#39;s Saved Shows 
[*LibraryApi*](doc/LibraryApi.md) | [**checkUsersSavedTracks**](doc/LibraryApi.md#checkuserssavedtracks) | **GET** /me/tracks/contains | Check User&#39;s Saved Tracks 
[*LibraryApi*](doc/LibraryApi.md) | [**createPlaylist**](doc/LibraryApi.md#createplaylist) | **POST** /users/{user_id}/playlists | Create Playlist 
[*LibraryApi*](doc/LibraryApi.md) | [**followArtistsUsers**](doc/LibraryApi.md#followartistsusers) | **PUT** /me/following | Follow Artists or Users 
[*LibraryApi*](doc/LibraryApi.md) | [**getAListOfCurrentUsersPlaylists**](doc/LibraryApi.md#getalistofcurrentusersplaylists) | **GET** /me/playlists | Get Current User&#39;s Playlists 
[*LibraryApi*](doc/LibraryApi.md) | [**getFollowed**](doc/LibraryApi.md#getfollowed) | **GET** /me/following | Get Followed Artists 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersSavedAlbums**](doc/LibraryApi.md#getuserssavedalbums) | **GET** /me/albums | Get User&#39;s Saved Albums 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersSavedAudiobooks**](doc/LibraryApi.md#getuserssavedaudiobooks) | **GET** /me/audiobooks | Get User&#39;s Saved Audiobooks 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersSavedEpisodes**](doc/LibraryApi.md#getuserssavedepisodes) | **GET** /me/episodes | Get User&#39;s Saved Episodes 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersSavedShows**](doc/LibraryApi.md#getuserssavedshows) | **GET** /me/shows | Get User&#39;s Saved Shows 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersSavedTracks**](doc/LibraryApi.md#getuserssavedtracks) | **GET** /me/tracks | Get User&#39;s Saved Tracks 
[*LibraryApi*](doc/LibraryApi.md) | [**getUsersTopArtistsAndTracks**](doc/LibraryApi.md#getuserstopartistsandtracks) | **GET** /me/top/{type} | Get User&#39;s Top Items 
[*LibraryApi*](doc/LibraryApi.md) | [**removeAlbumsUser**](doc/LibraryApi.md#removealbumsuser) | **DELETE** /me/albums | Remove Users&#39; Saved Albums 
[*LibraryApi*](doc/LibraryApi.md) | [**removeAudiobooksUser**](doc/LibraryApi.md#removeaudiobooksuser) | **DELETE** /me/audiobooks | Remove User&#39;s Saved Audiobooks 
[*LibraryApi*](doc/LibraryApi.md) | [**removeEpisodesUser**](doc/LibraryApi.md#removeepisodesuser) | **DELETE** /me/episodes | Remove User&#39;s Saved Episodes 
[*LibraryApi*](doc/LibraryApi.md) | [**removeShowsUser**](doc/LibraryApi.md#removeshowsuser) | **DELETE** /me/shows | Remove User&#39;s Saved Shows 
[*LibraryApi*](doc/LibraryApi.md) | [**removeTracksUser**](doc/LibraryApi.md#removetracksuser) | **DELETE** /me/tracks | Remove User&#39;s Saved Tracks 
[*LibraryApi*](doc/LibraryApi.md) | [**saveAlbumsUser**](doc/LibraryApi.md#savealbumsuser) | **PUT** /me/albums | Save Albums for Current User 
[*LibraryApi*](doc/LibraryApi.md) | [**saveAudiobooksUser**](doc/LibraryApi.md#saveaudiobooksuser) | **PUT** /me/audiobooks | Save Audiobooks for Current User 
[*LibraryApi*](doc/LibraryApi.md) | [**saveEpisodesUser**](doc/LibraryApi.md#saveepisodesuser) | **PUT** /me/episodes | Save Episodes for Current User 
[*LibraryApi*](doc/LibraryApi.md) | [**saveShowsUser**](doc/LibraryApi.md#saveshowsuser) | **PUT** /me/shows | Save Shows for Current User 
[*LibraryApi*](doc/LibraryApi.md) | [**saveTracksUser**](doc/LibraryApi.md#savetracksuser) | **PUT** /me/tracks | Save Tracks for Current User 
[*LibraryApi*](doc/LibraryApi.md) | [**unfollowArtistsUsers**](doc/LibraryApi.md#unfollowartistsusers) | **DELETE** /me/following | Unfollow Artists or Users 
[*MarketsApi*](doc/MarketsApi.md) | [**getAvailableMarkets**](doc/MarketsApi.md#getavailablemarkets) | **GET** /markets | Get Available Markets 
[*PlayerApi*](doc/PlayerApi.md) | [**addToQueue**](doc/PlayerApi.md#addtoqueue) | **POST** /me/player/queue | Add Item to Playback Queue 
[*PlayerApi*](doc/PlayerApi.md) | [**getAUsersAvailableDevices**](doc/PlayerApi.md#getausersavailabledevices) | **GET** /me/player/devices | Get Available Devices 
[*PlayerApi*](doc/PlayerApi.md) | [**getInformationAboutTheUsersCurrentPlayback**](doc/PlayerApi.md#getinformationabouttheuserscurrentplayback) | **GET** /me/player | Get Playback State 
[*PlayerApi*](doc/PlayerApi.md) | [**getQueue**](doc/PlayerApi.md#getqueue) | **GET** /me/player/queue | Get the User&#39;s Queue 
[*PlayerApi*](doc/PlayerApi.md) | [**getRecentlyPlayed**](doc/PlayerApi.md#getrecentlyplayed) | **GET** /me/player/recently-played | Get Recently Played Tracks 
[*PlayerApi*](doc/PlayerApi.md) | [**getTheUsersCurrentlyPlayingTrack**](doc/PlayerApi.md#gettheuserscurrentlyplayingtrack) | **GET** /me/player/currently-playing | Get Currently Playing Track 
[*PlayerApi*](doc/PlayerApi.md) | [**pauseAUsersPlayback**](doc/PlayerApi.md#pauseausersplayback) | **PUT** /me/player/pause | Pause Playback 
[*PlayerApi*](doc/PlayerApi.md) | [**seekToPositionInCurrentlyPlayingTrack**](doc/PlayerApi.md#seektopositionincurrentlyplayingtrack) | **PUT** /me/player/seek | Seek To Position 
[*PlayerApi*](doc/PlayerApi.md) | [**setRepeatModeOnUsersPlayback**](doc/PlayerApi.md#setrepeatmodeonusersplayback) | **PUT** /me/player/repeat | Set Repeat Mode 
[*PlayerApi*](doc/PlayerApi.md) | [**setVolumeForUsersPlayback**](doc/PlayerApi.md#setvolumeforusersplayback) | **PUT** /me/player/volume | Set Playback Volume 
[*PlayerApi*](doc/PlayerApi.md) | [**skipUsersPlaybackToNextTrack**](doc/PlayerApi.md#skipusersplaybacktonexttrack) | **POST** /me/player/next | Skip To Next 
[*PlayerApi*](doc/PlayerApi.md) | [**skipUsersPlaybackToPreviousTrack**](doc/PlayerApi.md#skipusersplaybacktoprevioustrack) | **POST** /me/player/previous | Skip To Previous 
[*PlayerApi*](doc/PlayerApi.md) | [**startAUsersPlayback**](doc/PlayerApi.md#startausersplayback) | **PUT** /me/player/play | Start/Resume Playback 
[*PlayerApi*](doc/PlayerApi.md) | [**toggleShuffleForUsersPlayback**](doc/PlayerApi.md#toggleshuffleforusersplayback) | **PUT** /me/player/shuffle | Toggle Playback Shuffle 
[*PlayerApi*](doc/PlayerApi.md) | [**transferAUsersPlayback**](doc/PlayerApi.md#transferausersplayback) | **PUT** /me/player | Transfer Playback 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**addTracksToPlaylist**](doc/PlaylistsApi.md#addtrackstoplaylist) | **POST** /playlists/{playlist_id}/tracks | Add Items to Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**changePlaylistDetails**](doc/PlaylistsApi.md#changeplaylistdetails) | **PUT** /playlists/{playlist_id} | Change Playlist Details 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**checkIfUserFollowsPlaylist**](doc/PlaylistsApi.md#checkifuserfollowsplaylist) | **GET** /playlists/{playlist_id}/followers/contains | Check if Users Follow Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**createPlaylist**](doc/PlaylistsApi.md#createplaylist) | **POST** /users/{user_id}/playlists | Create Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**followPlaylist**](doc/PlaylistsApi.md#followplaylist) | **PUT** /playlists/{playlist_id}/followers | Follow Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getACategoriesPlaylists**](doc/PlaylistsApi.md#getacategoriesplaylists) | **GET** /browse/categories/{category_id}/playlists | Get Category&#39;s Playlists 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getAListOfCurrentUsersPlaylists**](doc/PlaylistsApi.md#getalistofcurrentusersplaylists) | **GET** /me/playlists | Get Current User&#39;s Playlists 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getFeaturedPlaylists**](doc/PlaylistsApi.md#getfeaturedplaylists) | **GET** /browse/featured-playlists | Get Featured Playlists 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getListUsersPlaylists**](doc/PlaylistsApi.md#getlistusersplaylists) | **GET** /users/{user_id}/playlists | Get User&#39;s Playlists 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getPlaylist**](doc/PlaylistsApi.md#getplaylist) | **GET** /playlists/{playlist_id} | Get Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getPlaylistCover**](doc/PlaylistsApi.md#getplaylistcover) | **GET** /playlists/{playlist_id}/images | Get Playlist Cover Image 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**getPlaylistsTracks**](doc/PlaylistsApi.md#getplayliststracks) | **GET** /playlists/{playlist_id}/tracks | Get Playlist Items 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**removeTracksPlaylist**](doc/PlaylistsApi.md#removetracksplaylist) | **DELETE** /playlists/{playlist_id}/tracks | Remove Playlist Items 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**reorderOrReplacePlaylistsTracks**](doc/PlaylistsApi.md#reorderorreplaceplayliststracks) | **PUT** /playlists/{playlist_id}/tracks | Update Playlist Items 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**unfollowPlaylist**](doc/PlaylistsApi.md#unfollowplaylist) | **DELETE** /playlists/{playlist_id}/followers | Unfollow Playlist 
[*PlaylistsApi*](doc/PlaylistsApi.md) | [**uploadCustomPlaylistCover**](doc/PlaylistsApi.md#uploadcustomplaylistcover) | **PUT** /playlists/{playlist_id}/images | Add Custom Playlist Cover Image 
[*SearchApi*](doc/SearchApi.md) | [**search**](doc/SearchApi.md#search) | **GET** /search | Search for Item 
[*ShowsApi*](doc/ShowsApi.md) | [**checkUsersSavedShows**](doc/ShowsApi.md#checkuserssavedshows) | **GET** /me/shows/contains | Check User&#39;s Saved Shows 
[*ShowsApi*](doc/ShowsApi.md) | [**getAShow**](doc/ShowsApi.md#getashow) | **GET** /shows/{id} | Get Show 
[*ShowsApi*](doc/ShowsApi.md) | [**getAShowsEpisodes**](doc/ShowsApi.md#getashowsepisodes) | **GET** /shows/{id}/episodes | Get Show Episodes 
[*ShowsApi*](doc/ShowsApi.md) | [**getMultipleShows**](doc/ShowsApi.md#getmultipleshows) | **GET** /shows | Get Several Shows 
[*ShowsApi*](doc/ShowsApi.md) | [**getUsersSavedShows**](doc/ShowsApi.md#getuserssavedshows) | **GET** /me/shows | Get User&#39;s Saved Shows 
[*ShowsApi*](doc/ShowsApi.md) | [**removeShowsUser**](doc/ShowsApi.md#removeshowsuser) | **DELETE** /me/shows | Remove User&#39;s Saved Shows 
[*ShowsApi*](doc/ShowsApi.md) | [**saveShowsUser**](doc/ShowsApi.md#saveshowsuser) | **PUT** /me/shows | Save Shows for Current User 
[*TracksApi*](doc/TracksApi.md) | [**addTracksToPlaylist**](doc/TracksApi.md#addtrackstoplaylist) | **POST** /playlists/{playlist_id}/tracks | Add Items to Playlist 
[*TracksApi*](doc/TracksApi.md) | [**checkUsersSavedTracks**](doc/TracksApi.md#checkuserssavedtracks) | **GET** /me/tracks/contains | Check User&#39;s Saved Tracks 
[*TracksApi*](doc/TracksApi.md) | [**getAnAlbumsTracks**](doc/TracksApi.md#getanalbumstracks) | **GET** /albums/{id}/tracks | Get Album Tracks 
[*TracksApi*](doc/TracksApi.md) | [**getAnArtistsTopTracks**](doc/TracksApi.md#getanartiststoptracks) | **GET** /artists/{id}/top-tracks | Get Artist&#39;s Top Tracks 
[*TracksApi*](doc/TracksApi.md) | [**getAudioAnalysis**](doc/TracksApi.md#getaudioanalysis) | **GET** /audio-analysis/{id} | Get Track&#39;s Audio Analysis 
[*TracksApi*](doc/TracksApi.md) | [**getAudioFeatures**](doc/TracksApi.md#getaudiofeatures) | **GET** /audio-features/{id} | Get Track&#39;s Audio Features 
[*TracksApi*](doc/TracksApi.md) | [**getPlaylistsTracks**](doc/TracksApi.md#getplayliststracks) | **GET** /playlists/{playlist_id}/tracks | Get Playlist Items 
[*TracksApi*](doc/TracksApi.md) | [**getRecommendations**](doc/TracksApi.md#getrecommendations) | **GET** /recommendations | Get Recommendations 
[*TracksApi*](doc/TracksApi.md) | [**getSeveralAudioFeatures**](doc/TracksApi.md#getseveralaudiofeatures) | **GET** /audio-features | Get Tracks&#39; Audio Features 
[*TracksApi*](doc/TracksApi.md) | [**getSeveralTracks**](doc/TracksApi.md#getseveraltracks) | **GET** /tracks | Get Several Tracks 
[*TracksApi*](doc/TracksApi.md) | [**getTrack**](doc/TracksApi.md#gettrack) | **GET** /tracks/{id} | Get Track 
[*TracksApi*](doc/TracksApi.md) | [**getUsersSavedTracks**](doc/TracksApi.md#getuserssavedtracks) | **GET** /me/tracks | Get User&#39;s Saved Tracks 
[*TracksApi*](doc/TracksApi.md) | [**getUsersTopArtistsAndTracks**](doc/TracksApi.md#getuserstopartistsandtracks) | **GET** /me/top/{type} | Get User&#39;s Top Items 
[*TracksApi*](doc/TracksApi.md) | [**removeTracksPlaylist**](doc/TracksApi.md#removetracksplaylist) | **DELETE** /playlists/{playlist_id}/tracks | Remove Playlist Items 
[*TracksApi*](doc/TracksApi.md) | [**removeTracksUser**](doc/TracksApi.md#removetracksuser) | **DELETE** /me/tracks | Remove User&#39;s Saved Tracks 
[*TracksApi*](doc/TracksApi.md) | [**reorderOrReplacePlaylistsTracks**](doc/TracksApi.md#reorderorreplaceplayliststracks) | **PUT** /playlists/{playlist_id}/tracks | Update Playlist Items 
[*TracksApi*](doc/TracksApi.md) | [**saveTracksUser**](doc/TracksApi.md#savetracksuser) | **PUT** /me/tracks | Save Tracks for Current User 
[*UsersApi*](doc/UsersApi.md) | [**checkCurrentUserFollows**](doc/UsersApi.md#checkcurrentuserfollows) | **GET** /me/following/contains | Check If User Follows Artists or Users 
[*UsersApi*](doc/UsersApi.md) | [**checkIfUserFollowsPlaylist**](doc/UsersApi.md#checkifuserfollowsplaylist) | **GET** /playlists/{playlist_id}/followers/contains | Check if Users Follow Playlist 
[*UsersApi*](doc/UsersApi.md) | [**followArtistsUsers**](doc/UsersApi.md#followartistsusers) | **PUT** /me/following | Follow Artists or Users 
[*UsersApi*](doc/UsersApi.md) | [**followPlaylist**](doc/UsersApi.md#followplaylist) | **PUT** /playlists/{playlist_id}/followers | Follow Playlist 
[*UsersApi*](doc/UsersApi.md) | [**getCurrentUsersProfile**](doc/UsersApi.md#getcurrentusersprofile) | **GET** /me | Get Current User&#39;s Profile 
[*UsersApi*](doc/UsersApi.md) | [**getFollowed**](doc/UsersApi.md#getfollowed) | **GET** /me/following | Get Followed Artists 
[*UsersApi*](doc/UsersApi.md) | [**getListUsersPlaylists**](doc/UsersApi.md#getlistusersplaylists) | **GET** /users/{user_id}/playlists | Get User&#39;s Playlists 
[*UsersApi*](doc/UsersApi.md) | [**getUsersProfile**](doc/UsersApi.md#getusersprofile) | **GET** /users/{user_id} | Get User&#39;s Profile 
[*UsersApi*](doc/UsersApi.md) | [**getUsersTopArtistsAndTracks**](doc/UsersApi.md#getuserstopartistsandtracks) | **GET** /me/top/{type} | Get User&#39;s Top Items 
[*UsersApi*](doc/UsersApi.md) | [**unfollowArtistsUsers**](doc/UsersApi.md#unfollowartistsusers) | **DELETE** /me/following | Unfollow Artists or Users 
[*UsersApi*](doc/UsersApi.md) | [**unfollowPlaylist**](doc/UsersApi.md#unfollowplaylist) | **DELETE** /playlists/{playlist_id}/followers | Unfollow Playlist 


## Documentation For Models

 - [AddTracksToPlaylistRequest](doc/AddTracksToPlaylistRequest.md)
 - [AlbumBase](doc/AlbumBase.md)
 - [AlbumBaseExternalIds](doc/AlbumBaseExternalIds.md)
 - [AlbumBaseExternalUrls](doc/AlbumBaseExternalUrls.md)
 - [AlbumBaseRestrictions](doc/AlbumBaseRestrictions.md)
 - [AlbumObject](doc/AlbumObject.md)
 - [AlbumRestrictionObject](doc/AlbumRestrictionObject.md)
 - [ArtistObject](doc/ArtistObject.md)
 - [ArtistObjectExternalUrls](doc/ArtistObjectExternalUrls.md)
 - [ArtistObjectFollowers](doc/ArtistObjectFollowers.md)
 - [AudioAnalysisObject](doc/AudioAnalysisObject.md)
 - [AudioAnalysisObjectMeta](doc/AudioAnalysisObjectMeta.md)
 - [AudioAnalysisObjectTrack](doc/AudioAnalysisObjectTrack.md)
 - [AudioFeaturesObject](doc/AudioFeaturesObject.md)
 - [AudiobookBase](doc/AudiobookBase.md)
 - [AudiobookBaseExternalUrls](doc/AudiobookBaseExternalUrls.md)
 - [AudiobookObject](doc/AudiobookObject.md)
 - [AudiobookObjectAllOfChapters](doc/AudiobookObjectAllOfChapters.md)
 - [AuthorObject](doc/AuthorObject.md)
 - [CategoryObject](doc/CategoryObject.md)
 - [ChangePlaylistDetailsRequest](doc/ChangePlaylistDetailsRequest.md)
 - [ChapterBase](doc/ChapterBase.md)
 - [ChapterBaseRestrictions](doc/ChapterBaseRestrictions.md)
 - [ChapterObject](doc/ChapterObject.md)
 - [ChapterRestrictionObject](doc/ChapterRestrictionObject.md)
 - [ContextObject](doc/ContextObject.md)
 - [ContextObjectExternalUrls](doc/ContextObjectExternalUrls.md)
 - [CopyrightObject](doc/CopyrightObject.md)
 - [CreatePlaylistRequest](doc/CreatePlaylistRequest.md)
 - [CurrentlyPlayingContextObject](doc/CurrentlyPlayingContextObject.md)
 - [CurrentlyPlayingContextObjectActions](doc/CurrentlyPlayingContextObjectActions.md)
 - [CurrentlyPlayingContextObjectDevice](doc/CurrentlyPlayingContextObjectDevice.md)
 - [CurrentlyPlayingObject](doc/CurrentlyPlayingObject.md)
 - [CurrentlyPlayingObjectContext](doc/CurrentlyPlayingObjectContext.md)
 - [CurrentlyPlayingObjectItem](doc/CurrentlyPlayingObjectItem.md)
 - [CursorObject](doc/CursorObject.md)
 - [CursorPagingObject](doc/CursorPagingObject.md)
 - [CursorPagingObjectCursors](doc/CursorPagingObjectCursors.md)
 - [CursorPagingPlayHistoryObject](doc/CursorPagingPlayHistoryObject.md)
 - [CursorPagingSimplifiedArtistObject](doc/CursorPagingSimplifiedArtistObject.md)
 - [DeviceObject](doc/DeviceObject.md)
 - [DevicesObject](doc/DevicesObject.md)
 - [DisallowsObject](doc/DisallowsObject.md)
 - [EpisodeBase](doc/EpisodeBase.md)
 - [EpisodeBaseExternalUrls](doc/EpisodeBaseExternalUrls.md)
 - [EpisodeBaseRestrictions](doc/EpisodeBaseRestrictions.md)
 - [EpisodeBaseResumePoint](doc/EpisodeBaseResumePoint.md)
 - [EpisodeObject](doc/EpisodeObject.md)
 - [EpisodeRestrictionObject](doc/EpisodeRestrictionObject.md)
 - [ErrorObject](doc/ErrorObject.md)
 - [ExplicitContentSettingsObject](doc/ExplicitContentSettingsObject.md)
 - [ExternalIdObject](doc/ExternalIdObject.md)
 - [ExternalUrlObject](doc/ExternalUrlObject.md)
 - [FollowArtistsUsersRequest](doc/FollowArtistsUsersRequest.md)
 - [FollowPlaylistRequest](doc/FollowPlaylistRequest.md)
 - [FollowersObject](doc/FollowersObject.md)
 - [GetAUsersAvailableDevices200Response](doc/GetAUsersAvailableDevices200Response.md)
 - [GetAnAlbum401Response](doc/GetAnAlbum401Response.md)
 - [GetAnArtistsTopTracks200Response](doc/GetAnArtistsTopTracks200Response.md)
 - [GetAvailableMarkets200Response](doc/GetAvailableMarkets200Response.md)
 - [GetCategories200Response](doc/GetCategories200Response.md)
 - [GetFollowed200Response](doc/GetFollowed200Response.md)
 - [GetMultipleAlbums200Response](doc/GetMultipleAlbums200Response.md)
 - [GetMultipleArtists200Response](doc/GetMultipleArtists200Response.md)
 - [GetMultipleAudiobooks200Response](doc/GetMultipleAudiobooks200Response.md)
 - [GetMultipleEpisodes200Response](doc/GetMultipleEpisodes200Response.md)
 - [GetMultipleShows200Response](doc/GetMultipleShows200Response.md)
 - [GetNewReleases200Response](doc/GetNewReleases200Response.md)
 - [GetRecommendationGenres200Response](doc/GetRecommendationGenres200Response.md)
 - [GetSeveralAudioFeatures200Response](doc/GetSeveralAudioFeatures200Response.md)
 - [GetSeveralChapters200Response](doc/GetSeveralChapters200Response.md)
 - [GetUsersTopArtistsAndTracks200Response](doc/GetUsersTopArtistsAndTracks200Response.md)
 - [GetUsersTopArtistsAndTracks200ResponseAllOfItemsInner](doc/GetUsersTopArtistsAndTracks200ResponseAllOfItemsInner.md)
 - [ImageObject](doc/ImageObject.md)
 - [LinkedTrackObject](doc/LinkedTrackObject.md)
 - [LinkedTrackObjectExternalUrls](doc/LinkedTrackObjectExternalUrls.md)
 - [NarratorObject](doc/NarratorObject.md)
 - [PagingArtistObject](doc/PagingArtistObject.md)
 - [PagingFeaturedPlaylistObject](doc/PagingFeaturedPlaylistObject.md)
 - [PagingObject](doc/PagingObject.md)
 - [PagingPlaylistObject](doc/PagingPlaylistObject.md)
 - [PagingPlaylistTrackObject](doc/PagingPlaylistTrackObject.md)
 - [PagingSavedAlbumObject](doc/PagingSavedAlbumObject.md)
 - [PagingSavedEpisodeObject](doc/PagingSavedEpisodeObject.md)
 - [PagingSavedShowObject](doc/PagingSavedShowObject.md)
 - [PagingSavedTrackObject](doc/PagingSavedTrackObject.md)
 - [PagingSimplifiedAlbumObject](doc/PagingSimplifiedAlbumObject.md)
 - [PagingSimplifiedArtistObject](doc/PagingSimplifiedArtistObject.md)
 - [PagingSimplifiedAudiobookObject](doc/PagingSimplifiedAudiobookObject.md)
 - [PagingSimplifiedChapterObject](doc/PagingSimplifiedChapterObject.md)
 - [PagingSimplifiedEpisodeObject](doc/PagingSimplifiedEpisodeObject.md)
 - [PagingSimplifiedShowObject](doc/PagingSimplifiedShowObject.md)
 - [PagingSimplifiedTrackObject](doc/PagingSimplifiedTrackObject.md)
 - [PagingTrackObject](doc/PagingTrackObject.md)
 - [PlayHistoryObject](doc/PlayHistoryObject.md)
 - [PlayHistoryObjectContext](doc/PlayHistoryObjectContext.md)
 - [PlayHistoryObjectTrack](doc/PlayHistoryObjectTrack.md)
 - [PlayerErrorObject](doc/PlayerErrorObject.md)
 - [PlayerErrorReasons](doc/PlayerErrorReasons.md)
 - [PlaylistObject](doc/PlaylistObject.md)
 - [PlaylistObjectExternalUrls](doc/PlaylistObjectExternalUrls.md)
 - [PlaylistObjectFollowers](doc/PlaylistObjectFollowers.md)
 - [PlaylistObjectOwner](doc/PlaylistObjectOwner.md)
 - [PlaylistObjectTracks](doc/PlaylistObjectTracks.md)
 - [PlaylistOwnerObject](doc/PlaylistOwnerObject.md)
 - [PlaylistTrackObject](doc/PlaylistTrackObject.md)
 - [PlaylistTrackObjectAddedBy](doc/PlaylistTrackObjectAddedBy.md)
 - [PlaylistTrackObjectTrack](doc/PlaylistTrackObjectTrack.md)
 - [PlaylistTracksRefObject](doc/PlaylistTracksRefObject.md)
 - [PlaylistUserObject](doc/PlaylistUserObject.md)
 - [PrivateUserObject](doc/PrivateUserObject.md)
 - [PrivateUserObjectExplicitContent](doc/PrivateUserObjectExplicitContent.md)
 - [PrivateUserObjectExternalUrls](doc/PrivateUserObjectExternalUrls.md)
 - [PrivateUserObjectFollowers](doc/PrivateUserObjectFollowers.md)
 - [PublicUserObject](doc/PublicUserObject.md)
 - [PublicUserObjectExternalUrls](doc/PublicUserObjectExternalUrls.md)
 - [PublicUserObjectFollowers](doc/PublicUserObjectFollowers.md)
 - [QueueObject](doc/QueueObject.md)
 - [QueueObjectQueueInner](doc/QueueObjectQueueInner.md)
 - [RecommendationSeedObject](doc/RecommendationSeedObject.md)
 - [RecommendationsObject](doc/RecommendationsObject.md)
 - [RemoveEpisodesUserRequest](doc/RemoveEpisodesUserRequest.md)
 - [RemoveTracksPlaylistRequest](doc/RemoveTracksPlaylistRequest.md)
 - [RemoveTracksPlaylistRequestTracksInner](doc/RemoveTracksPlaylistRequestTracksInner.md)
 - [ReorderOrReplacePlaylistsTracks200Response](doc/ReorderOrReplacePlaylistsTracks200Response.md)
 - [ReorderOrReplacePlaylistsTracksRequest](doc/ReorderOrReplacePlaylistsTracksRequest.md)
 - [ResumePointObject](doc/ResumePointObject.md)
 - [SaveAlbumsUserRequest](doc/SaveAlbumsUserRequest.md)
 - [SaveEpisodesUserRequest](doc/SaveEpisodesUserRequest.md)
 - [SaveTracksUserRequest](doc/SaveTracksUserRequest.md)
 - [SavedAlbumObject](doc/SavedAlbumObject.md)
 - [SavedAlbumObjectAlbum](doc/SavedAlbumObjectAlbum.md)
 - [SavedEpisodeObject](doc/SavedEpisodeObject.md)
 - [SavedEpisodeObjectEpisode](doc/SavedEpisodeObjectEpisode.md)
 - [SavedShowObject](doc/SavedShowObject.md)
 - [SavedShowObjectShow](doc/SavedShowObjectShow.md)
 - [SavedTrackObject](doc/SavedTrackObject.md)
 - [SavedTrackObjectTrack](doc/SavedTrackObjectTrack.md)
 - [Search200Response](doc/Search200Response.md)
 - [SectionObject](doc/SectionObject.md)
 - [SegmentObject](doc/SegmentObject.md)
 - [ShowBase](doc/ShowBase.md)
 - [ShowBaseExternalUrls](doc/ShowBaseExternalUrls.md)
 - [ShowObject](doc/ShowObject.md)
 - [ShowObjectAllOfEpisodes](doc/ShowObjectAllOfEpisodes.md)
 - [SimplifiedAlbumObject](doc/SimplifiedAlbumObject.md)
 - [SimplifiedArtistObject](doc/SimplifiedArtistObject.md)
 - [SimplifiedAudiobookObject](doc/SimplifiedAudiobookObject.md)
 - [SimplifiedChapterObject](doc/SimplifiedChapterObject.md)
 - [SimplifiedEpisodeObject](doc/SimplifiedEpisodeObject.md)
 - [SimplifiedPlaylistObject](doc/SimplifiedPlaylistObject.md)
 - [SimplifiedPlaylistObjectTracks](doc/SimplifiedPlaylistObjectTracks.md)
 - [SimplifiedShowObject](doc/SimplifiedShowObject.md)
 - [SimplifiedTrackObject](doc/SimplifiedTrackObject.md)
 - [SimplifiedTrackObjectExternalUrls](doc/SimplifiedTrackObjectExternalUrls.md)
 - [SimplifiedTrackObjectLinkedFrom](doc/SimplifiedTrackObjectLinkedFrom.md)
 - [SimplifiedTrackObjectRestrictions](doc/SimplifiedTrackObjectRestrictions.md)
 - [StartAUsersPlaybackRequest](doc/StartAUsersPlaybackRequest.md)
 - [TimeIntervalObject](doc/TimeIntervalObject.md)
 - [TrackObject](doc/TrackObject.md)
 - [TrackObjectAlbum](doc/TrackObjectAlbum.md)
 - [TrackObjectExternalIds](doc/TrackObjectExternalIds.md)
 - [TrackRestrictionObject](doc/TrackRestrictionObject.md)
 - [TransferAUsersPlaybackRequest](doc/TransferAUsersPlaybackRequest.md)
 - [TuneableTrackObject](doc/TuneableTrackObject.md)
 - [UnfollowArtistsUsersRequest](doc/UnfollowArtistsUsersRequest.md)


## Documentation For Authorization


Authentication schemes defined for the API:
### oauth_2_0

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://accounts.spotify.com/authorize
- **Scopes**: 
 - **app-remote-control**: Communicate with the Spotify app on your device. 
 - **playlist-read-private**: Access your private playlists. 
 - **playlist-read-collaborative**: Access your collaborative playlists. 
 - **playlist-modify-public**: Manage your public playlists. 
 - **playlist-modify-private**: Manage your private playlists. 
 - **user-library-read**: Access your saved content. 
 - **user-library-modify**: Manage your saved content. 
 - **user-read-private**: Access your subscription details. 
 - **user-read-email**: Get your real email address. 
 - **user-follow-read**: Access your followers and who you are following. 
 - **user-follow-modify**: Manage your saved content. 
 - **user-top-read**: Read your top artists and content. 
 - **user-read-playback-position**: Read your position in content you have played. 
 - **user-read-playback-state**: Read your currently playing content and Spotify Connect devices information. 
 - **user-read-recently-played**: Access your recently played items. 
 - **user-read-currently-playing**: Read your currently playing content. 
 - **user-modify-playback-state**: Control playback on your Spotify clients and Spotify Connect devices. 
 - **ugc-image-upload**: Upload images to Spotify on your behalf. 
 - **streaming**: Play content and control playback on your other devices. 


## Author



